@@ -22,22 +22,19 @@ import sysconfig
 from rteval.modules.loads import LoadModules
 from rteval.modules.measurement import MeasurementModules, MeasurementProfile
 from rteval.rtevalReport import rtevalReport
-from rteval.rtevalXMLRPC import rtevalXMLRPC
 from rteval.Log import Log
 from rteval import rtevalConfig
-from rteval import rtevalMailer
 from rteval import version
 
 RTEVAL_VERSION = version.RTEVAL_VERSION
 
 earlystop = False
 
-stopsig_received = False
+stopsig = threading.Event()
 def sig_handler(signum, frame):
     """ Handle SIGINT (CTRL + C) or SIGTERM (Termination signal) """
     if signum in (signal.SIGINT, signal.SIGTERM):
-        global stopsig_received
-        stopsig_received = True
+        stopsig.set()
         print("*** stop signal received - stopping rteval run ***")
     else:
         raise RuntimeError(f"SIGNAL received! ({signum})")
@@ -70,13 +67,7 @@ class RtEval(rtevalReport):
         from .sysinfo import SystemInfo
         self._sysinfo = SystemInfo(self.__rtevcfg, logger=self.__logger)
 
-        # prepare a mailer, if that's configured
-        if self.__cfg.HasSection('smtp'):
-            self.__mailer = rtevalMailer.rtevalMailer(self.__cfg.GetSection('smtp'))
-        else:
-            self.__mailer = None
-
-        if not os.path.exists(self.__rtevcfg.xslt_report):
+        if not self.__rtevcfg.xslt_report or not os.path.exists(self.__rtevcfg.xslt_report):
             raise RuntimeError(f"can't find XSL template ({self.__rtevcfg.xslt_report})!")
 
         # Add rteval directory into module search path
@@ -91,19 +82,6 @@ class RtEval(rtevalReport):
         rtevalReport.__init__(self, self.__version,
                               self.__rtevcfg.installdir, self.__rtevcfg.annotate)
 
-        # If --xmlrpc-submit is given, check that we can access the server
-        if self.__rtevcfg.xmlrpc:
-            self.__xmlrpc = rtevalXMLRPC(self.__rtevcfg.xmlrpc, self.__logger, self.__mailer)
-            if not self.__xmlrpc.Ping():
-                if not self.__rtevcfg.xmlrpc_noabort:
-                    print(f"ERROR: Could not reach XML-RPC server '{self.__rtevcfg.xmlrpc}'.  Aborting.")
-                    sys.exit(2)
-                else:
-                    print("WARNING: Could not ping the XML-RPC server.  Will continue anyway.")
-        else:
-            self.__xmlrpc = None
-
-
     @staticmethod
     def __show_remaining_time(remaining):
         secs = int(remaining)
@@ -195,8 +173,6 @@ class RtEval(rtevalReport):
                 nthreads = threading.active_count()
             else:
                 nthreads = None
-            self.__logger.log(Log.INFO, "Waiting 30 seconds to let load modules settle down")
-            time.sleep(30)
             measure_profile.Unleash()
             measure_start = datetime.now()
 
@@ -208,8 +184,8 @@ class RtEval(rtevalReport):
             currtime = time.time()
             rpttime = currtime + report_interval
             load_avg_checked = 5
-            while (currtime <= stoptime) and not stopsig_received:
-                time.sleep(60.0)
+            while (currtime <= stoptime) and not stopsig.is_set():
+                stopsig.wait(min(stoptime - currtime, 60.0))
                 if not measure_profile.isAlive():
                     stoptime = currtime
                     earlystop = True
@@ -238,7 +214,7 @@ class RtEval(rtevalReport):
             signal.signal(signal.SIGTERM, signal.SIG_DFL)
 
         except RuntimeError as err:
-            if not stopsig_received:
+            if not stopsig.is_set():
                 raise RuntimeError(f"appeared during measurement: {err}")
 
         finally:
@@ -271,10 +247,6 @@ class RtEval(rtevalReport):
         if self.__rtevcfg.sysreport:
             self._sysinfo.run_sysreport(self.__reportdir)
 
-        # if --xmlrpc-submit | -X was given, send our report to the given host
-        if self.__xmlrpc:
-            rtevalres = self.__xmlrpc.SendReport(self.GetXMLreport())
-
         if earlystop:
             rtevalres = 1
         self._sysinfo.copy_dmesg(self.__reportdir)
